library jmb_aqualight;

import 'src/packets-discovery.dart' show createDiscoveryPacket;
import 'src/packets-live.dart' show createLivePackets;
import 'src/packets-schedule.dart' show createSchedulePackets;
import 'src/packets-sync.dart' show createTimeSyncPacket;
import 'src/send.dart' show sendPackets;

class ConnectionInfo {
  String channelBytes;

  ConnectionInfo(this.channelBytes);
}

Future<ConnectionInfo> connect() async {
  final packets = [createDiscoveryPacket()];
  final response = await sendPackets(packets);
  final channelBytes = response[0].substring(8, 32);
  return ConnectionInfo(channelBytes);
}

Future<void> liveSchedule(ConnectionInfo connectionInfo, List<List<int>> schedule,
    [smooth = true]) async {
  final packets =
      createLivePackets(connectionInfo.channelBytes, schedule, smooth);
  await sendPackets(packets);
}

Future<void> timeSync(ConnectionInfo connectionInfo) async {
  final packets = [createTimeSyncPacket(connectionInfo.channelBytes)];
  await sendPackets(packets);
}

Future<void> uploadSchedule(ConnectionInfo connectionInfo, List<List<int>> schedule) async {
  final packets = createSchedulePackets(connectionInfo.channelBytes, schedule);
  await sendPackets(packets);
}
